@@ -6,7 +6,7 @@ from pydantic import BaseModel
 
 
 class AgentCommandType(enum.Enum):
-    SET_CSS_CONFIG = "SET_CSS_CONFIG"
+    WRITE_FILE = "WRITE_FILE"
     EXEC_BASH = "EXEC_BASH"
     START_SERVICE = "START_SERVICE"
     STOP_SERVICE = "STOP_SERVICE"
@@ -43,13 +43,20 @@ class AgentCommandResult(BaseModel):
 
 class AgentCommand(BaseModel):
     id: int
-    test_fragment_id: int
+    experiment_id: Optional[int]
     created: datetime
     name: str  # hrn of the command, ignored by agent, but useful to inform users
     type: AgentCommandType
     # data:
     #   CSS config filename, or bash commands array, or service name. Type depends on AgentCommandType.
     #   (Dict[str, Any] is not used yet, but might be in the future)
+    #
+    # data type by AgentCommandType:
+    #   - WRITE_FILE -> List[str] with 2 elements ([filename, file_content])
+    #   - EXEC_BASH -> List[str] of command parts
+    #   - START_SERVICE -> str (service name)
+    #   - STOP_SERVICE -> str (service name)
+    #
     data: Union[str, List[str], Dict[str, Any]]
     timeout_s: float
 
